@@ -36,16 +36,16 @@
 // libtdescreensaver interface
 extern "C"
 {
-	KDE_EXPORT const char *kss_applicationName = "kgravity.kss";
-	KDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Gravity Screen Saver" );
-	KDE_EXPORT const char *kss_version = "2.2.0";
+	TDE_EXPORT const char *kss_applicationName = "kgravity.kss";
+	TDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Gravity Screen Saver" );
+	TDE_EXPORT const char *kss_version = "2.2.0";
 
-	KDE_EXPORT KScreenSaver *kss_create( WId id )
+	TDE_EXPORT KScreenSaver *kss_create( WId id )
 	{
 		return new KGravitySaver( id );
 	}
 
-	KDE_EXPORT TQDialog *kss_setup()
+	TDE_EXPORT TQDialog *kss_setup()
 	{
 		return new KGravitySetup();
 	}
