@@ -54,21 +54,21 @@
 extern "C"
 {
    /** application name for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_applicationName = "krotation.kss";
+   TDE_EXPORT const char *kss_applicationName = "krotation.kss";
    /** application description for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_description =
+   TDE_EXPORT const char *kss_description =
    I18N_NOOP("Simulation of a force free rotating asymmetric body");
    /** application version for the libtdescreensaver interface */
-   KDE_EXPORT const char *kss_version = KROTATION_VERSION;
+   TDE_EXPORT const char *kss_version = KROTATION_VERSION;
 
    /** function to create screen saver object */
-   KDE_EXPORT  KScreenSaver* kss_create(WId id)
+   TDE_EXPORT  KScreenSaver* kss_create(WId id)
    {
       return new KRotationSaver(id);
    }
 
    /** function to create setup dialog for screen saver */
-   KDE_EXPORT TQDialog* kss_setup()
+   TDE_EXPORT TQDialog* kss_setup()
    {
       return new KRotationSetup();
    }
@@ -491,7 +491,7 @@ KRotationSaver::KRotationSaver(WId id)
 
    timer = new TQTimer(this);
    timer->start(deltaT, TRUE);
-   connect(timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(doTimeStep()));
+   connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(doTimeStep()));
 }
 
 KRotationSaver::~KRotationSaver()
@@ -754,8 +754,8 @@ KRotationSetup::KRotationSetup(TQWidget* parent, const char* name)
    // if the preview area is resized it emmits the resized() event which is
    // caught by the saver.  The embedded GlArea is resized to fit into the
    // preview area.
-   connect(preview, TQT_SIGNAL(resized(TQResizeEvent*)),
-           saver,   TQT_SLOT(resizeGlArea(TQResizeEvent*)));
+   connect(preview, TQ_SIGNAL(resized(TQResizeEvent*)),
+           saver,   TQ_SLOT(resizeGlArea(TQResizeEvent*)));
 }
 
 KRotationSetup::~KRotationSetup()
