@@ -803,7 +803,7 @@ bool StdFactory::supports( Ability ability )
 
 extern "C"
 {
-	KDE_EXPORT KDecorationFactory *create_factory()
+	TDE_EXPORT KDecorationFactory *create_factory()
 	{
                 return new TDE1::StdFactory();
 	}
